
@font-face {
  font-family: 'Roboto Mono';
  font-style: normal;
  font-weight: bold;
  src: url("./fonts_mono/RobotoMono-Bold.ttf") format('truetype');
}

@font-face {
  font-family: 'Roboto Mono';
  font-style: italic;
  font-weight: bold;
  src: url("./fonts_mono/RobotoMono-BoldItalic.ttf") format('truetype');
}

@font-face {
  font-family: 'Roboto Mono';
  font-style: italic;
  font-weight: normal;
  src: url("./fonts_mono/RobotoMono-Italic.ttf") format('truetype');
}


@font-face {
  font-family: 'Roboto Mono';
  font-style: normal;
  font-weight: 300;
  src: url("./fonts_mono/RobotoMono-Light.ttf") format('truetype');
}


@font-face {
  font-family: 'Roboto Mono';
  font-style: italic;
  font-weight: 300;
  src: url("./fonts_mono/RobotoMono-LightItalic.ttf") format('truetype');
}




@font-face {
  font-family: 'Roboto Mono';
  font-style: normal;
  font-weight: 500;
  src: url("./fonts_mono/RobotoMono-Medium.ttf") format('truetype');
}



@font-face {
  font-family: 'Roboto Mono';
  font-style: italic;
  font-weight: 500;
  src: url("./fonts_mono/RobotoMono-MediumItalic.ttf") format('truetype');
}



@font-face {
  font-family: 'Roboto Mono';
  font-style: normal;
  font-weight: 400;
  src: url("./fonts_mono/RobotoMono-Regular.ttf") format('truetype');
}


@font-face {
  font-family: 'Roboto Mono';
  font-style: normal;
  font-weight: 100;
  src: url("./fonts_mono/RobotoMono-Thin.ttf") format('truetype');
}



@font-face {
  font-family: 'Roboto Mono';
  font-style: italic;
  font-weight: 100;
  src: url("./fonts_mono/ThinItalic-Thin.ttf") format('truetype');
}
