{% autoescape None %}

<html>

  <head>
    <meta charset="utf-8">
    <script type="text/javascript" src="/static/brython.js"></script>
    <script type="text/javascript" src="/static/brython_stdlib.js"></script>
    <script type="text/javascript" src="/static/material-components-web/material-components-web.min.js"></script>
    <link rel="stylesheet" type="text/css" href="/static/material-components-web/material-components-web.min.css">
    <!--<link rel="stylesheet" type="text/css" href="/static/material-components-web/theme.css">-->
    <link rel="stylesheet" type="text/css" href="/theme.css">

    <!--Fonts-->
    <link type="text/css" rel="stylesheet" href="/static/fonts/fontawesome-free-5.5.0-web/css/all.min.css">
    <link type="text/css" rel="stylesheet" href="/static/fonts/roboto-android/roboto.css">
    <link type="text/css" rel="stylesheet" href="/static/fonts/roboto-android/roboto-mono.css">

    <!--Material Icons-->
    <link type="text/css" rel="stylesheet" href="/static/fonts/material-design-icons-3.0.1/iconfont/material-icons.css">
    <!--<link type="text/css" rel="stylesheet" href="/static/fonts/mdi/css/materialdesignicons.min.css">-->

    {% block html_head %}{% end %}


    <script type="text/python">
import sys
from radiant.utils import fake
{% for module in mock_imports %}
sys.modules["{{module}}"] = fake()
{% end %}
    </script>


    <script type="text/python">
import sys
sys.path.append('/root/')
sys.path.append('/static/Lib/site-packages/')

{% if path %}
sys.path.append('/path/')
{% end %}

from radiant.utils import autoinit
from {{file}} import {{class_}}

argvs = {{argv}}

{% block module_init %}
{{class_}}(None, {{python_}})
{% end %}

autoinit()

    </script>

  </head>

  <body onload="brython(1)">

  </body>

</html>
